@@ -2,6 +2,7 @@
 from http.cookies import SimpleCookie
 import sys
 import json
+import logging
 sys.path.insert(0,'../scrapinglib')
 from scrapinglib import getSupportedSources
 from scrapinglib import search as orignal_search
@@ -24,6 +25,7 @@ proxydict = {
 def search(number, source=None, **kwargs):
     """ test
     """
+    logging.basicConfig(level=logging.DEBUG)
     data = orignal_search(number, source, **kwargs)
     beaty = json.dumps(data, ensure_ascii=False, sort_keys=True, indent=4, separators=(',', ':'))
     return beaty
@@ -105,11 +107,11 @@ print(f"supported sources: {sources}")
 # print(search("080520-001", 'carib', proxies=proxydict))
 # print(search('080520-001', specifiedSource='carib', specifiedUrl='https://www.caribbeancom.com/moviepages/080520-001/index.html', proxies=proxydict))
 
-# print(search('91CM-121', 'mv91', proxies=proxydict))
-# print(search('91CM-122', 'mv91', proxies=proxydict))
-# print(search('91CM-143', 'mv91', proxies=proxydict))
-# print(search('91MS-006', 'mv91', proxies=proxydict))
-# print(search('91MS-006', specifiedSource='mv91', specifiedUrl='https://www.91mv.org/index/detail?id=108J9W', proxies=proxydict))
+# print(search('91CM-121', 'javday', proxies=proxydict))
+# print(search('91CM-122', 'javday', proxies=proxydict))
+# print(search('91CM-143', 'javday', proxies=proxydict))
+# print(search('91MS-006', 'javday', proxies=proxydict))
+# print(search('91MS-006', specifiedSource='javday', specifiedUrl='https://www.91mv.org/index/detail?id=108J9W', proxies=proxydict))
 
 # print(search('GCOLLE-840724', 'gcolle', proxies=proxydict))
 # print(search('840724', 'gcolle', proxies=proxydict))
